// Cilindro.cpp  (C) 2000 adolfo@di-mare.com

/** \file  Cilindro.cpp
    \brief Implementaciones para la clase \c Cilindro.

    \author Adolfo Di Mare <adolfo@di-mare.com>
    \date   2005
*/

// Fig. 9.10: cylindr2.cpp
// Member and friend function definitions 
// for class Cilindro.

#include "cilindro.h"

namespace ADH {

// Cilindro constructor calls Circulo constructor
Cilindro::Cilindro( double h, double r, int x, int y )
   : Circulo( r, x, y )   // call base-class constructor
{
    Altura( h );
//  Dibuje(cout);
}

void Cilindro::Altura( double h )  {
// Set m_altura of Cilindro
    m_altura = ( h >= 0 ? h : 0 );
}

#define _USE_MATH_DEFINES
#include <math.h>

/// Calcula el area del Cilindro (i.e., la superficie del area)
double Cilindro::Area() const {
    return  2 * Circulo::Area() +
          ( 2 * M_PI * Radio() ) * m_altura;
}

/// Calcula el volumen del Cilindro.
double Cilindro::Volumen() const {
    return Circulo::Area() * m_altura;
}

/// Despliega el objeto en el flujo de salida \c output.
void Cilindro::Dibuje(ostream& output) const {
    output << *this;
}

/// Grabp \c en \c output.
ostream &operator<< ( ostream &output, const Cilindro &c ) {
// Output Cilindro dimensions

    output << endl;
    c.Traslada_X(output);

    output << "Cilindro [ X() = " << c.X()
           <<  ", Y() = " << c.Y()
           << " || Radio = "
           << setiosflags( ios::fixed | ios::showpoint )
           << setprecision( 2 ) << c.Radio()
           << " | Altura = "
           << setiosflags( ios::fixed | ios::showpoint )
           << setprecision( 2 ) << c.Altura()
           << " ]";

    return output;   // enables cascaded calls
}
} // namespace ADH
// EOF: Cilindro.cpp